==> bettertrims-4.0.0%2B1.21.1-fabric-sources.jar: com/bawnorton/bettertrims/client/tooltip/condition/predicate/data/PartialDataComponentPredicateTooltipAdders.java <==
//~ item_data_predicates
package com.bawnorton.bettertrims.client.tooltip.condition.predicate.data;

import com.bawnorton.bettertrims.client.tooltip.condition.predicate.data.partial.*;
import com.bawnorton.bettertrims.client.tooltip.component.CompositeContainerComponent;
import com.bawnorton.bettertrims.client.tooltip.condition.LootConditionTooltips;
import com.bawnorton.bettertrims.client.tooltip.condition.predicate.PredicateTooltip;
import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_638;
import net.minecraft.class_9360;
import net.minecraft.class_9361;

public final class PartialDataComponentPredicateTooltipAdders {
	public static final Map</*$ item_data_predicate >>*/ class_9360 .class_8745<?>, PartialAdder<? extends /*$ item_data_predicate >>*/ class_9360 >> PARTIAL_ADDER_MAP = new HashMap<>();

	static {
		register(class_9361.field_51392, new AttributeModifiersPartialAdder());
		register(class_9361.field_51393, new TrimPredicatePartialAdder());
		register(class_9361.field_51387, new BundlePredicatePartialAdder());
		register(class_9361.field_51386, new ContainerPredicatePartialAdder());
		register(class_9361.field_49810, new CustomDataPredicatePartialAdder());
		register(class_9361.field_49806, new DamagePredicatePartialAdder());
		register(class_9361.field_49807, new EnchantmentsPredicatePartialAdder<>());
		register(class_9361.field_51388, new FireworkExplosionPredicatePartialAdder());
		register(class_9361.field_51389, new FireworksPredicatePartialAdder());
		register(class_9361.field_49808, new EnchantmentsPredicatePartialAdder<>());
		register(class_9361.field_49809, new PotionsPredicatePartialAdder());
		register(class_9361.field_51390, new WritableBookPartialAdder());
		register(class_9361.field_51391, new WrittenBookPartialAdder());
	}

	private static <T extends /*$ item_data_predicate >>*/ class_9360 > void register(/*$ item_data_predicate >>*/ class_9360 .class_8745<T> type, PartialAdder<T> adder) {
		if (PARTIAL_ADDER_MAP.containsKey(type)) {
			throw new IllegalStateException("Duplicate data component predicate type: " + type);
		}
		PARTIAL_ADDER_MAP.put(type, adder);
	}

	@SuppressWarnings("unchecked")
	public static void addToBuilder(class_638 level, /*$ item_data_predicate >>*/ class_9360 .class_8745<?> type, /*$ item_data_predicate >>*/ class_9360 predicate, LootConditionTooltips.State state, CompositeContainerComponent.Builder builder) {
		PartialAdder</*$ item_data_predicate >>*/ class_9360 > adder = (PartialAdder</*$ item_data_predicate >>*/ class_9360 >) PARTIAL_ADDER_MAP.getOrDefault(type, PartialAdder.UNKNOWN.apply(type));
		adder.addToBuilder(level, predicate, state, builder);
	}

	public static String key(String key) {
		return PredicateTooltip.key("data.partial.%s".formatted(key));
	}
}

==> bettertrims-4.0.2%2B1.21.10-fabric-sources.jar: com/bawnorton/bettertrims/client/tooltip/condition/predicate/data/PartialDataComponentPredicateTooltipAdders.java <==
//~ item_data_predicates
package com.bawnorton.bettertrims.client.tooltip.condition.predicate.data;

import com.bawnorton.bettertrims.client.tooltip.condition.predicate.data.partial.*;
import com.bawnorton.bettertrims.client.tooltip.component.CompositeContainerComponent;
import com.bawnorton.bettertrims.client.tooltip.condition.LootConditionTooltips;
import com.bawnorton.bettertrims.client.tooltip.condition.predicate.PredicateTooltip;
import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_638;
import net.minecraft.class_9360;
import net.minecraft.class_9361;
//? if >=1.21.8 {
import net.minecraft.core.component.predicates.*;
//?} else {
/*import net.minecraft.core.component.predicates.DataComponentPredicates;
import net.minecraft.core.component.predicates.DataComponentPredicate;
*///?}

public final class PartialDataComponentPredicateTooltipAdders {
	public static final Map</*$ item_data_predicate >>*/ class_9360 .class_8745<?>, PartialAdder<? extends /*$ item_data_predicate >>*/ class_9360 >> PARTIAL_ADDER_MAP = new HashMap<>();

	static {
		register(class_9361.field_51392, new AttributeModifiersPartialAdder());
		register(class_9361.field_51393, new TrimPredicatePartialAdder());
		register(class_9361.field_51387, new BundlePredicatePartialAdder());
		register(class_9361.field_51386, new ContainerPredicatePartialAdder());
		register(class_9361.field_49810, new CustomDataPredicatePartialAdder());
		register(class_9361.field_49806, new DamagePredicatePartialAdder());
		register(class_9361.field_49807, new EnchantmentsPredicatePartialAdder<>());
		register(class_9361.field_51388, new FireworkExplosionPredicatePartialAdder());
		register(class_9361.field_51389, new FireworksPredicatePartialAdder());
		register(class_9361.field_49808, new EnchantmentsPredicatePartialAdder<>());
		register(class_9361.field_49809, new PotionsPredicatePartialAdder());
		register(class_9361.field_51390, new WritableBookPartialAdder());
		register(class_9361.field_51391, new WrittenBookPartialAdder());
		register(class_9361.field_52024, new JukeboxPlayablePartialAdder());
	}

	private static <T extends /*$ item_data_predicate >>*/ class_9360 > void register(/*$ item_data_predicate >>*/ class_9360 .class_8745<T> type, PartialAdder<T> adder) {
		if (PARTIAL_ADDER_MAP.containsKey(type)) {
			throw new IllegalStateException("Duplicate data component predicate type: " + type);
		}
		PARTIAL_ADDER_MAP.put(type, adder);
	}

	@SuppressWarnings("unchecked")
	public static void addToBuilder(class_638 level, /*$ item_data_predicate >>*/ class_9360 .class_8745<?> type, /*$ item_data_predicate >>*/ class_9360 predicate, LootConditionTooltips.State state, CompositeContainerComponent.Builder builder) {
		PartialAdder</*$ item_data_predicate >>*/ class_9360 > adder = (PartialAdder</*$ item_data_predicate >>*/ class_9360 >) PARTIAL_ADDER_MAP.getOrDefault(type, PartialAdder.UNKNOWN.apply(type));
		adder.addToBuilder(level, predicate, state, builder);
	}

	public static String key(String key) {
		return PredicateTooltip.key("data.partial.%s".formatted(key));
	}
}
